@@ -1,6 +1,6 @@
 /* (c) 2002-2004 by Marcin Wiacek */
 
-#include "../../../common/gsmstate.h"
+#include "../../../libgammu/gsmstate.h"
 
 #ifdef GSM_ENABLE_NOKIA_DCT4
 
@@ -8,11 +8,14 @@
 
 #include "dct4.h"
 #include "../../gammu.h"
-#include "../../../common/phone/pfunc.h"
-#include "../../../common/phone/nokia/nfunc.h"
-#include "../../../common/phone/nokia/dct4s40/dct4func.h"
-#include "../../../common/misc/coding/coding.h"
-#include "../../../common/misc/locales.h"
+#include "../../../libgammu/phone/pfunc.h"
+#include "../../../libgammu/phone/nokia/nfunc.h"
+#include "../../../libgammu/phone/nokia/dct4s40/dct4func.h"
+#include "../../../libgammu/misc/coding/coding.h"
+#include "../../../helper/locales.h"
+
+#include "../../../helper/formats.h"
+#include "../../../helper/string.h"
 
 extern GSM_Reply_Function UserReplyFunctions4[];
 
@@ -24,19 +27,19 @@ extern GSM_Reply_Function UserReplyFunctions4[];
 
 /* ------- some usefull functions ----------------------------------------- */
 
-GSM_Error CheckDCT4Only()
+GSM_Error CheckDCT4Only(void)
 {
-	bool found = false;
+	gboolean found = FALSE;
 
 	/* Checking if phone is DCT4 */
 #ifdef GSM_ENABLE_NOKIA3650
- 	if (strstr(N3650Phone.models, gsm->Phone.Data.ModelInfo->model) != NULL) found = true;
+ 	if (strstr(N3650Phone.models, gsm->Phone.Data.ModelInfo->model) != NULL) found = TRUE;
 #endif
 #ifdef GSM_ENABLE_NOKIA6510
- 	if (strstr(N6510Phone.models, gsm->Phone.Data.ModelInfo->model) != NULL) found = true;
+ 	if (strstr(N6510Phone.models, gsm->Phone.Data.ModelInfo->model) != NULL) found = TRUE;
 #endif
 #ifdef GSM_ENABLE_NOKIA3320
- 	if (strstr(N3320Phone.models, gsm->Phone.Data.ModelInfo->model) != NULL) found = true;
+ 	if (strstr(N3320Phone.models, gsm->Phone.Data.ModelInfo->model) != NULL) found = TRUE;
 #endif
 	if (!found) return ERR_NOTSUPPORTED;
 
@@ -49,7 +52,7 @@ GSM_Error CheckDCT4Only()
 	return ERR_NONE;
 }
 
-static void CheckDCT4()
+void CheckDCT4(void)
 {
 	GSM_Error error;
 
@@ -60,14 +63,14 @@ static void CheckDCT4()
 		break;
 	case ERR_OTHERCONNECTIONREQUIRED:
 		printf("%s\n", _("Can't do it with current phone protocol"));
-		GSM_TerminateConnection(gsm);
-		exit(-1);
+		GSM_Terminate();
+		Terminate(3);
 	default:
 		break;
 	}
 }
 
-static bool answer_yes2(char *text)
+static gboolean answer_yes2(const char *text)
 {
     	int         len;
     	char        ans[99];
@@ -75,9 +78,9 @@ static bool answer_yes2(char *text)
 	while (1) {
 		printf(_("%s (yes/no) ? "),text);
 		len=GetLine(stdin, ans, 99);
-		if (len==-1) exit(-1);
-		if (strcasecmp(ans, _("yes")) == 0) return true;
-		if (strcasecmp(ans, _("no")) == 0) return false;
+		if (len==-1) Terminate(3);
+		if (strcasecmp(ans, _("yes")) == 0) return TRUE;
+		if (strcasecmp(ans, _("no")) == 0) return FALSE;
 	}
 }
 
@@ -294,7 +297,7 @@ void DCT4SetPhoneMenus(int argc, char *argv[])
 	}
 
 	if (current == 10) {
-		printf("%s\n", _("Sorry, but configuration matrix for this model is not added yet. Please report"));
+		printf("%s\n", _("Sorry, but configuration matrix for this model has not yet been added. See <http://wammu.eu/support/bugs/> for information how to report it."));
 		return;
 	}
 
@@ -328,16 +331,16 @@ static GSM_Error DCT4_ReplyTestsNames(GSM_Protocol_Message msg, GSM_StateMachine
 static GSM_Error DCT4_ReplyTestsStartup(GSM_Protocol_Message msg, GSM_StateMachine *sm)
 {
 	int 	 i,pos,j;
-	bool	 found;
+	gboolean	 found;
 
 	pos = 10;
 
 	for (i=0;i<msg.Buffer[8];i++) {
-		found = false;
+		found = FALSE;
 		for (j=0;j<DCT4Tests.Num;j++) {
 			if (DCT4Tests.Tests[j].ID == msg.Buffer[pos]) {
-				DCT4Tests.Tests[j].Startup 	= true;
-				found 				= true;
+				DCT4Tests.Tests[j].Startup 	= TRUE;
+				found 				= TRUE;
 				break;
 			}
 		}
@@ -403,7 +406,7 @@ void DCT4SelfTests(int argc, char *argv[])
 	error=GSM_WaitFor (gsm, GetNames, 6, 0x35, 4, ID_User1);
 	Print_Error(error);
 
-	for (j=0;j<DCT4Tests.Num;j++) DCT4Tests.Tests[j].Startup = false;
+	for (j=0;j<DCT4Tests.Num;j++) DCT4Tests.Tests[j].Startup = FALSE;
 
 	error=GSM_WaitFor (gsm, GetDoneST, 6, 0x35, 4, ID_User3);
 	Print_Error(error);
@@ -419,14 +422,14 @@ static GSM_Error DCT4_ReplyVibra(GSM_Protocol_Message msg, GSM_StateMachine *sm)
 {
 #ifdef DEBUG
 	switch (msg.Buffer[3]) {
-		case 0x0D : dbgprintf("Vibra state set OK\n"); break;
-		case 0x0F : dbgprintf("Vibra power set OK\n"); break;
+		case 0x0D : smprintf(sm, "Vibra state set OK\n"); break;
+		case 0x0F : smprintf(sm, "Vibra power set OK\n"); break;
 	}
 #endif
 	return ERR_NONE;
 }
 
-static GSM_Error DCT4EnableVibra(GSM_StateMachine *sm, bool enable)
+static GSM_Error DCT4EnableVibra(GSM_StateMachine *sm, gboolean enable)
 {
 	/* Enables or disables vibra */
 	unsigned char 	Control[6] = {N7110_FRAME_HEADER,0x0C,
@@ -440,7 +443,7 @@ static GSM_Error DCT4EnableVibra(GSM_StateMachine *sm, bool enable)
 void DCT4SetVibraLevel(int argc, char *argv[])
 {
 	GSM_DateTime	Date;
-	unsigned int	i,j;
+	int	i,j;
 	GSM_Error error;
 
 	/* Set vibra level */
@@ -448,7 +451,7 @@ void DCT4SetVibraLevel(int argc, char *argv[])
 				       0x64,	/* Vibra power (in percent) */
 				       0x00};
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
         CheckDCT4();
 
@@ -458,7 +461,7 @@ void DCT4SetVibraLevel(int argc, char *argv[])
 	error=GSM_WaitFor (gsm, SetLevel, 6, 0x1C, 4, ID_User3);
 	Print_Error(error);
 
-	error=DCT4EnableVibra(gsm, true);
+	error=DCT4EnableVibra(gsm, TRUE);
 	Print_Error(error);
 
 	for (i=0;i<3;i++) {
@@ -470,7 +473,7 @@ void DCT4SetVibraLevel(int argc, char *argv[])
 		}
 	}
 
-	error=DCT4EnableVibra(gsm, false);
+	error=DCT4EnableVibra(gsm, FALSE);
 	Print_Error(error);
 
 	GSM_Terminate();
@@ -485,13 +488,13 @@ void DCT4VibraTest(int argc, char *argv[])
 
 	gsm->User.UserReplyFunctions=UserReplyFunctions4;
 
-	error=DCT4EnableVibra(gsm, true);
+	error=DCT4EnableVibra(gsm, TRUE);
 	Print_Error(error);
 
 	printf("%s\n", _("Press any key to continue..."));
 	GetLine(stdin, ans, 99);
 
-	error=DCT4EnableVibra(gsm, false);
+	error=DCT4EnableVibra(gsm, FALSE);
 	Print_Error(error);
 }
 
@@ -588,9 +591,9 @@ static GSM_Error DCT4_ReplyGetVoiceRecord(GSM_Protocol_Message msg, GSM_StateMac
 
 	switch (msg.Buffer[3]) {
 	case 0x05:
-		dbgprintf("Part of voice record received\n");
+		smprintf(sm, "Part of voice record received\n");
 		if (msg.Length == 6) {
-			dbgprintf("Empty\n");
+			smprintf(sm, "Empty\n");
 			return ERR_EMPTY;
 		}
  		*sm->Phone.Data.VoiceRecord = 0;
@@ -601,21 +604,20 @@ static GSM_Error DCT4_ReplyGetVoiceRecord(GSM_Protocol_Message msg, GSM_StateMac
 		}
 		return ERR_NONE;
 	case 0x0D:
-		dbgprintf("Last part of voice record is %02x %02x\n",msg.Buffer[11],msg.Buffer[12]);
-		dbgprintf("Token is %02x\n",msg.Buffer[13]);
+		smprintf(sm, "Last part of voice record is %02x %02x\n",msg.Buffer[11],msg.Buffer[12]);
+		smprintf(sm, "Token is %02x\n",msg.Buffer[13]);
  		sm->Phone.Data.PhoneString[0] = msg.Buffer[11];
  		sm->Phone.Data.PhoneString[1] = msg.Buffer[12];
  		sm->Phone.Data.PhoneString[2] = msg.Buffer[13];
 		return ERR_NONE;
-		break;
 	case 0x31:
-		dbgprintf("Names of voice records received\n");
+		smprintf(sm, "Names of voice records received\n");
 		j = 33;
-		for (i=0;i<msg.Buffer[9];i++) {
+		for (i = 0; i < (size_t)msg.Buffer[9]; i++) {
 			memcpy(Buffer,msg.Buffer+(j+1),msg.Buffer[j]);
 			Buffer[msg.Buffer[j]] 	= 0;
 			Buffer[msg.Buffer[j]+1] = 0;
-			dbgprintf(SIZE_T_FORMAT ". \"%s\"\n",i+1,DecodeUnicodeString(Buffer));
+			smprintf(sm, "%ld. \"%s\"\n",(long)i+1,DecodeUnicodeString(Buffer));
  			if (i==*sm->Phone.Data.VoiceRecord) {
  				sprintf(sm->Phone.Data.PhoneString,"%s->wav",DecodeUnicodeString(Buffer));
 				return ERR_NONE;
@@ -684,7 +686,7 @@ void DCT4GetVoiceRecord(int argc, char *argv[])
 	}
 	Location--;
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
         CheckDCT4();
 
@@ -692,13 +694,13 @@ void DCT4GetVoiceRecord(int argc, char *argv[])
 
 	gsm->Phone.Data.VoiceRecord 	= &Location;
 	gsm->Phone.Data.PhoneString 	= FileName;
-	dbgprintf("Getting voice record name\n");
+	smprintf(gsm, "Getting voice record name\n");
 	error=GSM_WaitFor (gsm, ReqNames, 14, 0x4A, 4, ID_User4);
 	Print_Error(error);
 
 	gsm->Phone.Data.PhoneString 	= Buffer;
 	ReqToken[7] 			= Location;
-	dbgprintf("Getting voice record token\n");
+	smprintf(gsm, "Getting voice record token\n");
 	error=GSM_WaitFor (gsm, ReqToken, 10, 0x23, 4, ID_User4);
 	Print_Error(error);
 	TokenLocation 			= Buffer[0] * 256 + Buffer[1];
@@ -718,7 +720,7 @@ void DCT4GetVoiceRecord(int argc, char *argv[])
 	ReqGet[7]			= Location;
 	fprintf(stderr,"Getting voice record and saving to \"%s\": ",FileName);
 	while (1) {
-		dbgprintf("Getting next part of voice record\n");
+		smprintf(gsm, "Getting next part of voice record\n");
 		fprintf(stderr,".");
 		error=GSM_WaitFor (gsm, ReqGet, 18, 0x23, 4, ID_User4);
 		if (error == ERR_NONE) {
@@ -732,7 +734,7 @@ void DCT4GetVoiceRecord(int argc, char *argv[])
 		ReqGet[12] = CurrentLocation % 256;
 		if (CurrentLocation+4 > TokenLocation) break;
 	}
-	dbgprintf("Getting first part in last sequence of voice record\n");
+	smprintf(gsm, "Getting first part in last sequence of voice record\n");
 	for (i=255;i>=0;i--) {
 		ReqGet[16] = i;
 		ReqGet[17] = Token;
@@ -746,7 +748,7 @@ void DCT4GetVoiceRecord(int argc, char *argv[])
 		if (error != ERR_EMPTY) Print_Error(error);
 	}
 	while (1) {
-		dbgprintf("Getting next part of last sequence in voice record\n");
+		smprintf(gsm, "Getting next part of last sequence in voice record\n");
 		CurrentLocation += 4;
 		ReqGet[11] = CurrentLocation / 256;
 		ReqGet[12] = CurrentLocation % 256;
@@ -805,10 +807,10 @@ static GSM_Error DCT4_ReplyGetSimlock(GSM_Protocol_Message msg, GSM_StateMachine
 
 	switch (msg.Buffer[3]) {
 	case 0x0D:
-		dbgprintf("Simlock info received\n");
-		dbgprintf("Config_Data: ");
+		smprintf(sm, "Simlock info received\n");
+		smprintf(sm, "Config_Data: ");
 		for (i=14;i<22;i++) {
-			dbgprintf("%02x",msg.Buffer[i]);
+			smprintf(sm, "%02x",msg.Buffer[i]);
 		}
 		sprintf(buff,"%02x%02x%02x",msg.Buffer[14],msg.Buffer[15],msg.Buffer[16]);
 		buff[6] = 0;
@@ -822,21 +824,21 @@ static GSM_Error DCT4_ReplyGetSimlock(GSM_Protocol_Message msg, GSM_StateMachine
 				buff);
 		}
 
-		dbgprintf("\n");
-		dbgprintf("Profile_Bits: ");
+		smprintf(sm, "\n");
+		smprintf(sm, "Profile_Bits: ");
 		for (i=22;i<30;i++) {
-			dbgprintf("%02x",msg.Buffer[i]);
+			smprintf(sm, "%02x",msg.Buffer[i]);
 		}
-		dbgprintf("\n");
+		smprintf(sm, "\n");
 		return ERR_NONE;
 	case 0x13:
-		dbgprintf("Simlock info received\n");
+		smprintf(sm, "Simlock info received\n");
 		if (msg.Buffer[58] == 0x05 && msg.Buffer[59] == 0x02) {
-			dbgprintf("SIM_PATH: ");
+			smprintf(sm, "SIM_PATH: ");
 			for (i=44;i<52;i++) {
-				dbgprintf("%02x",msg.Buffer[i]);
+				smprintf(sm, "%02x",msg.Buffer[i]);
 			}
-			dbgprintf("\n");
+			smprintf(sm, "\n");
 			printf(LISTFORMAT, _("Simlock data"));
 			for (i=60;i<63;i++) {
 				printf("%02x",msg.Buffer[i]);
@@ -848,16 +850,18 @@ static GSM_Error DCT4_ReplyGetSimlock(GSM_Protocol_Message msg, GSM_StateMachine
 	return ERR_UNKNOWNRESPONSE;
 }
 
-void DCT4Info(int argc, char *argv[])
+GSM_Error DCT4Info(void)
 {
 	unsigned char GetBTAddress[8] = {N6110_FRAME_HEADER, 0x09, 0x19, 0x01, 0x03, 0x06};
 	unsigned char GetSimlock[5] = {N6110_FRAME_HEADER, 0x12, 0x0D};
 	unsigned char value[10];
 	GSM_Error error;
 
-        if (CheckDCT4Only()!=ERR_NONE) return;
+	error = CheckDCT4Only();
+	if (error != ERR_NONE) return error;
 
-	if (GSM_IsPhoneFeatureAvailable(gsm->Phone.Data.ModelInfo, F_SERIES40_30)) return;
+	if (GSM_IsPhoneFeatureAvailable(gsm->Phone.Data.ModelInfo, F_SERIES40_30))
+		return ERR_NOTSUPPORTED;
 
 	gsm->User.UserReplyFunctions=UserReplyFunctions4;
 
@@ -879,6 +883,7 @@ void DCT4Info(int argc, char *argv[])
 	error=NOKIA_GetPhoneString(gsm,"\x00\x03\x02\x07\x00\x08",6,0x1b,value,ID_User6,10);
 	Print_Error(error);
 	printf(LISTFORMAT "%s\n", _("UEM"), value);
+	return ERR_NONE;
 }
 
 static FILE *T9File;
@@ -927,7 +932,7 @@ void DCT4GetT9(int argc, char *argv[])
 		Print_Error(error);
 		if (i==0) {
 			T9Dictionary = T9FullSize;
-			dbgprintf("T9 dictionary size is %i\n",T9Dictionary);
+			smprintf(gsm, "T9 dictionary size is %i\n",T9Dictionary);
 		}
 		i+=T9Size;
 	}
@@ -937,13 +942,13 @@ void DCT4GetT9(int argc, char *argv[])
 
 #ifdef GSM_ENABLE_NOKIA6510
 
-extern GSM_Error N6510_SetLight(GSM_StateMachine *sm, N6510_PHONE_LIGHTS light, bool enable);
+extern GSM_Error N6510_SetLight(GSM_StateMachine *sm, N6510_PHONE_LIGHTS light, gboolean enable);
 
 void DCT4SetLight(int argc, char *argv[])
 {
 	int			i;
 	N6510_PHONE_LIGHTS 	type;
-	bool			enable;
+	gboolean			enable;
 	GSM_Error error;
 
 	if (strcasecmp(argv[2],"display") == 0) { 	type = N6510_LIGHT_DISPLAY;
@@ -951,22 +956,22 @@ void DCT4SetLight(int argc, char *argv[])
 	} else if (strcasecmp(argv[2],"torch") == 0) {	type = N6510_LIGHT_TORCH;
 	} else {
 		printf(_("What lights should I enable (\"%s\") ?\n"),argv[2]);
-		exit(-1);
+		Terminate(3);
 	}
 
-	if (strcasecmp(argv[3],"on") == 0) { 		enable = true;
-	} else if (strcasecmp(argv[3],"off") == 0) {	enable = false;
+	if (strcasecmp(argv[3],"on") == 0) { 		enable = TRUE;
+	} else if (strcasecmp(argv[3],"off") == 0) {	enable = FALSE;
 	} else {
 		printf(_("What should I do (\"%s\") ?\n"),argv[3]);
-		exit(-1);
+		Terminate(3);
 	}
 
 	for (i=0;i<gsm->ConfigNum;i++) {
 		free(gsm->Config[i].StartInfo);
-		gsm->Config[i].StartInfo = strdup("false");
+		gsm->Config[i].StartInfo = strdup("FALSE");
 	}
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
         CheckDCT4();
 
@@ -1009,40 +1014,40 @@ static GSM_Error DCT4_ReplyGetADC(GSM_Protocol_Message msg, GSM_StateMachine *sm
 	if (msg.Buffer[6] == 0xff && msg.Buffer[7] == 0xff) return ERR_NONE;
 	switch (msg.Buffer[3]) {
 	case 0x10:
-		printf(_("raw "));
-		printf("%10i ",msg.Buffer[8]*256+msg.Buffer[9]);
+		/* l10n: Raw data for A/D convertor */
+		printf(_("raw result %10i "),msg.Buffer[8]*256+msg.Buffer[9]);
 		break;
 	case 0x12:
-		printf(_("unit result "));
-		printf("%10i ",(msg.Buffer[8]*256+msg.Buffer[9])*ADC);
+		/* l10n: Processed data for A/D convertor */
+		printf(_("unit result %10i "),(msg.Buffer[8]*256+msg.Buffer[9])*ADC);
 		break;
 	}
 	return ERR_NONE;
 }
 
 struct DCT4ADCInfo {
-	char 	*name;
-	char 	*unit;
+	const char 	*name;
+	const char 	*unit;
 	int 	x;
 };
 
 static struct DCT4ADCInfo DCT4ADC[] = {
-	{"Battery voltage, divided:",		"mV",  1},
-	{"Battery voltage, scaled:",		"mV",  1},
-	{"Charger voltage:",			"mV",  1},
-	{"Charger current:",			"mA",  1},
-	{"Battery size indicator:",		"Ohms",100},
-	{"Battery temperature:",		"K",   1},
-	{"Headset interconnection:",		"mV",  1},
-	{"Hook interconnection:",		"mV",  1},
-	{"Light sensor:",			"mV",  1},
-	{"Power amplifier temperature:",	"K",   1},
-	{"VCXO temperature:",			"K",   1},
-	{"Resistive keyboard 1/headint2:",	"mV",  1},
-	{"Resistive keyboard 1/auxdet:",	"mV",  1},
-	{"Initial battery voltage:",		"mV",  1},
-	{"Battery Current:",			"mA",  1},
-	{"Battery Current Fast:",		"mA",  1},
+	{N_("Battery voltage, divided:"),	N_("mV"),  1},
+	{N_("Battery voltage, scaled:"),	N_("mV"),  1},
+	{N_("Charger voltage:"),		N_("mV"),  1},
+	{N_("Charger current:"),		N_("mA"),  1},
+	{N_("Battery size indicator:"),		N_("Ohms"),100},
+	{N_("Battery temperature:"),		N_("K"),   1},
+	{N_("Headset interconnection:"),	N_("mV"),  1},
+	{N_("Hook interconnection:"),		N_("mV"),  1},
+	{N_("Light sensor:"),			N_("mV"),  1},
+	{N_("Power amplifier temperature:"),	N_("K"),   1},
+	{N_("VCXO temperature:"),		N_("K"),   1},
+	{N_("Resistive keyboard 1/headint2:"),	N_("mV"),  1},
+	{N_("Resistive keyboard 1/auxdet:"),	N_("mV"),  1},
+	{N_("Initial battery voltage:"),	N_("mV"),  1},
+	{N_("Battery Current:"),		N_("mA"),  1},
+	{N_("Battery Current Fast:"),		N_("mA"),  1},
 
 	{"", "", 1}
 };
@@ -1063,7 +1068,7 @@ void DCT4GetADC(int argc, char *argv[])
 	gsm->User.UserReplyFunctions=UserReplyFunctions4;
 
 	while (1) {
-		printf(" %30s ",DCT4ADC[i].name);
+		printf(" %30s ", gettext(DCT4ADC[i].name));
 		GetRaw[4] = i;
 		error=GSM_WaitFor (gsm, GetRaw, 6, 0x17, 4, ID_User3);
 		Print_Error(error);
@@ -1071,7 +1076,7 @@ void DCT4GetADC(int argc, char *argv[])
 		ADC		= DCT4ADC[i].x;
 		error=GSM_WaitFor (gsm, GetUnit, 6, 0x17, 4, ID_User3);
 		Print_Error(error);
-		printf("%s\n",DCT4ADC[i].unit);
+		printf("%s\n", gettext(DCT4ADC[i].unit));
 		i++;
 		if (DCT4ADC[i].name[0] == 0x00) break;
 	}
@@ -1117,7 +1122,7 @@ void DCT4TuneRadio(int argc, char *argv[])
 	GSM_Error error;
  	GSM_FMStation 	FMStation[50],FMStat;
 	int		i, j, num;
-	bool		found;
+	gboolean		found;
 
 	unsigned char Enable[]     = {N6110_FRAME_HEADER, 0x00, 0x00, 0x00};
 	unsigned char Disable[]    = {N6110_FRAME_HEADER, 0x01, 0x0E, 0x00};
@@ -1139,7 +1144,7 @@ void DCT4TuneRadio(int argc, char *argv[])
 //	unsigned char SetMono[]    = {N6110_FRAME_HEADER, 0x19,
 //				      0x09, 0x00, 0x96};
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
         CheckDCT4();
 
@@ -1150,14 +1155,14 @@ void DCT4TuneRadio(int argc, char *argv[])
 	if (error != ERR_NONE && error != ERR_EMPTY) {
 		printf("%s\n", _("Phone seems not to support radio"));
 		GSM_Terminate();
-		exit(-1);
+		Terminate(3);
 	}
 
 	error=GSM_WaitFor (gsm, Enable, 6, 0x3E, 4, ID_User3);
 	if (error == ERR_PERMISSION) {
 		printf("%s\n", _("Please connect headset. Required as antenna"));
 		GSM_Terminate();
-		exit(-1);
+		Terminate(3);
 	}
 	Print_Error(error);
 
@@ -1171,7 +1176,7 @@ void DCT4TuneRadio(int argc, char *argv[])
 
 		error=GSM_WaitFor (gsm, Find2, 10, 0x3E, 4, ID_User3);
 		Print_Error(error);
-		found = false;
+		found = FALSE;
 		for (j=0;j<num;j++) {
 			if (FMStation[j].Frequency > RadioFreq) {
 				diff = FMStation[j].Frequency - RadioFreq;
@@ -1179,13 +1184,13 @@ void DCT4TuneRadio(int argc, char *argv[])
 				diff = RadioFreq - FMStation[j].Frequency;
 			}
 			if (diff <= 0.2) {
-				dbgprintf("diff is %f\n",diff);
-				found = true;
+				smprintf(gsm, "diff is %f\n",diff);
+				found = TRUE;
 				break;
 			}
 		}
 		if (!found) {
-			dbgprintf("Adding %f, num %i\n",RadioFreq,num);
+			smprintf(gsm, "Adding %f, num %i\n",RadioFreq,num);
 			FMStation[num].Frequency = RadioFreq;
 			CopyUnicodeString(FMStation[num].StationName,RadioName);
 			num++;
@@ -1248,7 +1253,7 @@ void DCT4PlaySavedRingtone(int argc, char *argv[])
 	GSM_Error error;
 //	int i;
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
         CheckDCT4();
 
@@ -1292,7 +1297,7 @@ void DCT4MakeCameraShoot(int argc, char *argv[])
 	unsigned char CameraOFF[] = {N6110_FRAME_HEADER, 0x04, 0x01, 0x00};
 	GSM_Error error;
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
         CheckDCT4();
 
@@ -1331,7 +1336,7 @@ void DCT4GetScreenDump(int argc, char *argv[])
 	GSM_Error error;
 	//n6110_frameheader 06//screen info
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
         CheckDCT4();
 
@@ -1340,7 +1345,7 @@ void DCT4GetScreenDump(int argc, char *argv[])
 	error=GSM_WaitFor (gsm, req, 6, 0x0E, 4, ID_User3);
 	Print_Error(error);
 	len = 2000;
-	while (len >= 200) GSM_ReadDevice(gsm,true);
+	while (len >= 200) GSM_ReadDevice(gsm,TRUE);
 
 	GSM_Terminate();
 }
@@ -1355,8 +1360,8 @@ static GSM_Error DCT4_ReplyGetPBKFeatures(GSM_Protocol_Message msg, GSM_StateMac
 		printf(_("  entry ID %02X"),msg.Buffer[pos+4]);
 		switch (msg.Buffer[pos+4]) {
 		case N7110_PBK_SIM_SPEEDDIAL	: printf(_(" (Speed dial on SIM)")); 			break;
-		case N7110_PBK_NAME	    	: printf(_(" (Text: name (always the only one)"));		break;
-		case N7110_PBK_EMAIL	    	: printf(_(" (Text: email adress)"));			break;
+		case N7110_PBK_NAME	    	: printf(_(" (Text: name (always the only one))"));		break;
+		case N7110_PBK_EMAIL	    	: printf(_(" (Text: email address)"));			break;
 		case N7110_PBK_POSTAL	    	: printf(_(" (Text: postal address)"));			break;
 		case N7110_PBK_NOTE	    	: printf(_(" (Text: note)"));				break;
 		case N7110_PBK_NUMBER 	    	: printf(_(" (Phone number)"));				break;
@@ -1370,9 +1375,9 @@ static GSM_Error DCT4_ReplyGetPBKFeatures(GSM_Protocol_Message msg, GSM_StateMac
 
 		/* DCT4 only */
 		case N6510_PBK_URL		: printf(_(" (Text: URL address)"));			break;
-		case N6510_PBK_SMSLIST_ID	: printf(_(" (SMS list assigment)"));			break;
-		case N6510_PBK_VOICETAG_ID	: printf(_(" (Voice tag assigment)"));			break;
-		case N6510_PBK_PICTURE_ID	: printf(_(" (Picture ID assigment)"));			break;
+		case N6510_PBK_SMSLIST_ID	: printf(_(" (SMS list assignment)"));			break;
+		case N6510_PBK_VOICETAG_ID	: printf(_(" (Voice tag assignment)"));			break;
+		case N6510_PBK_PICTURE_ID	: printf(_(" (Picture ID assignment)"));			break;
 		case N6510_PBK_RINGTONEFILE_ID  : printf(_(" (Ringtone ID from filesystem/internal)"));	break;
 		case N6510_PBK_USER_ID          : printf(_(" (Text: user ID)"));				break;
 		case N6510_PBK_UNKNOWN2	        : printf(_(" (conversation list ID)"));			break;
@@ -1426,13 +1431,13 @@ void DCT4GetPBKFeatures(int argc, char *argv[])
 	if (strcasecmp(argv[2],"FD") == 0) MemoryType=MEM_FD;
 	if (MemoryType==0) {
 		printf(_("ERROR: unknown memory type (\"%s\")\n"),argv[2]);
-		exit (-1);
+		Terminate(2);
 	}
 
 	req[4] = NOKIA_GetMemoryType(gsm, MemoryType,N71_65_MEMORY_TYPES);
-	if (req[4]==0xff) exit(-1);
+	if (req[4]==0xff) Terminate(3);
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
         CheckDCT4();
 
