@@ -24,8 +24,10 @@
 #include "calendar.h"
 #include "misc.h"
 
-#include "smsd/smsdcore.h"
-#include "../common/misc/locales.h"
+#include "../helper/locales.h"
+#include "../helper/printing.h"
+#include "../helper/string.h"
+
 #ifdef DEBUG
 #  include "sniff.h"
 #endif
@@ -50,7 +52,7 @@
 
 #define ALL_MEMORY_TYPES "DC|MC|RC|ON|VM|SM|ME|MT|FD|SL"
 
-#define RSS_URL "http://blog.cihar.com/archives/gammu_releases/index-rss.xml"
+#define RSS_URL "http://wammu.eu/news/rss/"
 #define RSS_STABLE_STRING "Gammu stable version "
 #define RSS_TESTING_STRING "Gammu test version "
 
@@ -108,7 +110,7 @@ static void ListNetworks(int argc, char *argv[])
 		if (!*country) {
 			printf(_("Unknown country name: %s."), argv[2]);
 			printf("\n");
-			exit(-1);
+			Terminate(3);
 		}
 	}
 	printf("%-10s %s\n", _("Network"), _("Name"));
@@ -128,7 +130,7 @@ static void ListNetworks(int argc, char *argv[])
 	}
 }
 
-static void PrintVersion()
+static void PrintVersion(void)
 {
 	printf(_("[Gammu version %s built %s on %s using %s]"),
 	       VERSION, __TIME__, __DATE__, GetCompiler());
@@ -205,6 +207,9 @@ static void Features(int argc UNUSED, char *argv[]UNUSED)
 #ifdef GSM_ENABLE_BLUEOBEX
 	printf("  - %s\n", "BLUEOBEX");
 #endif
+#ifdef LIBUSB_FOUND
+	printf("  - %s\n", "FBUSUSB");
+#endif
 
 	printf(" * %s\n", _("Phones"));
 #ifdef GSM_ENABLE_NOKIA650
@@ -249,6 +254,7 @@ static void Features(int argc UNUSED, char *argv[]UNUSED)
 #ifdef GSM_ENABLE_GNAPGEN
 	printf("  - %s\n", "GNAPGEN");
 #endif
+	printf("  - %s\n", "DUMMY");
 
 	printf(" * %s\n", _("Miscellaneous"));
 #ifdef GSM_ENABLE_CELLBROADCAST
@@ -266,12 +272,6 @@ static void Features(int argc UNUSED, char *argv[]UNUSED)
 #ifdef CURL_FOUND
 	printf("  - %s\n", "CURL");
 #endif
-#ifdef HAVE_MYSQL_MYSQL_H
-	printf("  - %s\n", "MYSQL");
-#endif
-#ifdef HAVE_POSTGRESQL_LIBPQ_FE_H
-	printf("  - %s\n", "POSTGRESQL");
-#endif
 }
 
 /**
@@ -304,15 +304,15 @@ int VersionToInt(const char *Buffer)
 static void CheckVersion(int argc, char *argv[])
 {
 	GSM_File RSS;
-	bool checkstable = true;
-	bool checktest = true;
+	gboolean checkstable = TRUE;
+	gboolean checktest = TRUE;
 	const char *pos;
 	char new_version[20];
 	size_t i;
 
 	if (argc >= 3) {
-		if (strcasecmp(argv[2], "stable") == 0) {
-			checktest = false;
+		if (strcasecmp(argv[2], "STABLE") == 0) {
+			checktest = FALSE;
 		}
 	}
 
@@ -327,7 +327,7 @@ static void CheckVersion(int argc, char *argv[])
 		if (pos != NULL) {
 			pos += strlen(RSS_STABLE_STRING);
 
-			for (i = 0; i < sizeof(new_version) - 1 && (isdigit(pos[i]) || pos[i] == '.'); i++) {
+			for (i = 0; i < sizeof(new_version) - 1 && (isdigit((int)pos[i]) || pos[i] == '.'); i++) {
 				new_version[i] = pos[i];
 			}
 
@@ -345,7 +345,7 @@ static void CheckVersion(int argc, char *argv[])
 		if (pos != NULL) {
 			pos += strlen(RSS_TESTING_STRING);
 
-			for (i = 0; i < sizeof(new_version) - 1 && (isdigit(pos[i]) || pos[i] == '.'); i++) {
+			for (i = 0; i < sizeof(new_version) - 1 && (isdigit((int)pos[i]) || pos[i] == '.'); i++) {
 				new_version[i] = pos[i];
 			}
 
@@ -365,22 +365,24 @@ static void Version(int argc UNUSED, char *argv[]UNUSED)
 {
 	PrintVersion();
 
-	printf("%s\n", _("This is free software.  You may redistribute copies of it under the terms of"));
-	printf("%s\n", _("the GNU General Public License <http://www.gnu.org/licenses/gpl.html>."));
+	printf("%s\n", _("Copyright (C) 2003 - 2009 Michal Cihar <michal@cihar.com> and other authors."));
+
+	printf("\n");
+
+	printf("%s\n", _("License GPLv2: GNU GPL version 2 <http://creativecommons.org/licenses/GPL/2.0/>."));
+
+	printf("%s\n", _("This is free software: you are free to change and redistribute it."));
+
 	printf("%s\n", _("There is NO WARRANTY, to the extent permitted by law."));
-	printf("\n\n");
+
+	printf("\n");
+
+	printf("%s\n", _("Check <http://wammu.eu/gammu/> for updates."));
+
+	printf("\n");
 }
 
-#ifdef DEBUG
-/**
- * Function for testing purposes.
- */
-static void Foo(int argc UNUSED, char *argv[]UNUSED)
-{
-}
-#endif
-
-int ProcessParameters(char start, int argc, char *argv[]);
+int ProcessParameters(int start, int argc, char *argv[]);
 
 /**
  * Reads commands from file (argv[2]) or stdin and executes them
@@ -395,10 +397,11 @@ static void RunBatch(int argc, char *argv[])
 	 * @todo Allocate memory dynamically.
 	 */
 	char ln[2000];
-	size_t i;
+	size_t i, len;
+	ssize_t pos;
 	int j, c = 0, argsc;
 	char *argsv[20];
-	bool origbatch;
+	gboolean origbatch;
 	char *name;
 	char std_name[] = N_("standard input");
 
@@ -417,17 +420,25 @@ static void RunBatch(int argc, char *argv[])
 
 	argsv[0] = argv[0];
 	origbatch = batch;
-	batch = true;
+	batch = TRUE;
 	while (!feof(bf)) {
 		ln[0] = 0;
 		if (fgets(ln, sizeof(ln) - 2, bf) == NULL) {
-			printf_err(_("Error reading batch! Terminating.\n"));
+			if (!feof(bf)) {
+				printf_err(_("Error reading batch! Terminating.\n"));
+			} else {
+				printf_info(_("Batch processed, terminating.\n"));
+			}
 			break;
 		}
-		if (ln[strlen(ln) - 2] == 0x0D) {
-			/* reduce CRLF to LF so we have the same EOL on Windows and Linux */
-			ln[strlen(ln) - 2] = 0x0A;
-			ln[strlen(ln) - 1] = 0;
+
+		/* Skip all traling whitespace */
+		for (pos = strlen(ln) - 1; pos >= 0; pos--) {
+			if (isspace((int)ln[pos])) {
+				ln[pos] = 0;
+			} else {
+				break;
+			}
 		}
 
 		if (strlen(ln) < 1 || ln[0] == '#') {
@@ -439,8 +450,9 @@ static void RunBatch(int argc, char *argv[])
 		i = 0;
 		j = 0;
 		argsc = 0;
-		while (i < strlen(ln)) {
-			if (ln[i] == ' ' || ln[i] == 0x0A) {
+		len = strlen(ln);
+		while (i <= len) {
+			if (ln[i] == ' ' || ln[i] == 0) {
 				argsc++;
 				argsv[argsc] = malloc(i - j + 1);
 				strncpy(argsv[argsc], ln + j, i - j);
@@ -452,7 +464,7 @@ static void RunBatch(int argc, char *argv[])
 		if (argsc > 0) {
 			/* we have some usable command and parameters, send them into standard processing */
 			printf ("----------------------------------------------------------------------------\n");
-			printf(_("Executing batch \"%s\" - command %i: %s"), name, ++c, ln);
+			printf(_("Executing batch \"%s\" - command %i: %s\n"), name, ++c, ln);
 			/**
 			 * @todo Handle return value from ProcessParameters.
 			 */
@@ -464,7 +476,7 @@ static void RunBatch(int argc, char *argv[])
 	}
 	if (!origbatch) {
 		/* only close the batch if we are not in a nested batch */
-		batch = false;
+		batch = FALSE;
 		if (batchConn) {
 			GSM_Terminate();
 		}
@@ -472,18 +484,30 @@ static void RunBatch(int argc, char *argv[])
 	fclose(bf);
 }
 
+NORETURN
+void SendSMSDSMSObsolete(int argc, char *argv[])
+{
+	printf_err("%s\n", _("SMS daemon is now in separate binary, please use gammu-smsd-inject instead of gammu sendsmsdsms!"));
+	Terminate(100);
+}
+
+NORETURN
+void SMSDaemonObsolete(int argc, char *argv[])
+{
+	printf_err("%s\n", _("SMS daemon is now in separate binary, please use gammu-smsd instead of gammu smsd!"));
+	Terminate(100);
+}
+
 void Help(int argc, char *argv[]);
 
 static GSM_Parameters Parameters[] = {
 /* *INDENT-OFF* */
-#ifdef DEBUG
-	{"foo",			0, 0, Foo,			{0},				""},
-#endif
-	{"help",			0, 1, Help,			{H_Gammu,0},			""},
+	{"help",			0, 1, Help,			{H_Gammu,0},			"[topic]"},
 	{"identify",			0, 0, Identify,			{H_Info,0},			""},
 	{"version",			0, 0, Version,			{H_Gammu,0},			""},
 	{"features",			0, 0, Features,			{H_Gammu,0},			""},
-	{"checkversion",		0, 1, CheckVersion,		{H_Gammu,0},			"[stable]"},
+	{"checkversion",		0, 1, CheckVersion,		{H_Gammu,0},			"[STABLE]"},
+	{"checkfirmware",		0, 0, CheckFirmware,		{H_Info,0},			""},
 	{"getdisplaystatus",		0, 0, GetDisplayStatus,		{H_Info,0},			""},
 	{"monitor",			0, 1, Monitor,			{H_Info,H_Network,H_Call,0},	"[times]"},
 	{"setautonetworklogin",	0, 0, SetAutoNetworkLogin,	{H_Network,0},			""},
@@ -498,7 +522,7 @@ static GSM_Parameters Parameters[] = {
 	{"getrootfolders",		0, 0, GetRootFolders,		{H_Filesystem,0},		""},
 	{"setfileattrib",		1, 5, SetFileAttrib,		{H_Filesystem,0},		"folderID [-system] [-readonly] [-hidden] [-protected]"},
 	{"getfiles",			1,40, GetFiles,			{H_Filesystem,0},		"ID1, ID2, ..."},
-	{"addfile",			2, 6, AddSendFile,		{H_Filesystem,0},		"folderID name [-type JAR|BMP|PNG|GIF|JPG|MIDI|WBMP|AMR|3GP|NRT][-readonly][-protected][-system][-hidden][-newtime]"},
+	{"addfile",			2, 9, AddSendFile,		{H_Filesystem,0},		"folderID name [-type JAR|BMP|PNG|GIF|JPG|MIDI|WBMP|AMR|3GP|NRT][-readonly][-protected][-system][-hidden][-newtime]"},
 	{"sendfile",			1, 1, AddSendFile,		{H_Filesystem,0},		"name"},
 	{"deletefiles",		1,20, DeleteFiles,		{H_Filesystem,0},		"fileID"},
 #if defined(GSM_ENABLE_NOKIA_DCT3) || defined(GSM_ENABLE_NOKIA_DCT4)
@@ -521,6 +545,7 @@ static GSM_Parameters Parameters[] = {
 	{"listmemorycategory",	1, 1, ListMemoryCategory,	{H_Memory, H_Category,0},	"text|number"},
 	{"getfmstation",		1, 2, GetFMStation,		{H_FM,0},			"start [stop]"},
 	{"getsmsc",			0, 2, GetSMSC,			{H_SMS,0},			"[start [stop]]"},
+	{"setsmsc",			2, 2, SetSMSC,			{H_SMS,0},			"location number"},
 	{"getsms",			2, 3, GetSMS,			{H_SMS,0},			"folder start [stop]"},
 	{"deletesms",			2, 3, DeleteSMS,		{H_SMS,0},			"folder start [stop]"},
 	{"deleteallsms",		1, 1, DeleteAllSMS,		{H_SMS,0},			"folder"},
@@ -528,7 +553,7 @@ static GSM_Parameters Parameters[] = {
 	{"getallsms",			0, 1, GetAllSMS,		{H_SMS,0},			"-pbk"},
 	{"geteachsms",		0, 1, GetEachSMS,		{H_SMS,0},			"-pbk"},
 
-#define SMS_TEXT_OPTIONS	"[-inputunicode][-16bit][-flash][-len len][-autolen len][-unicode][-enablevoice][-disablevoice][-enablefax][-disablefax][-enableemail][-disableemail][-voidsms][-replacemessages ID][-replacefile file]"
+#define SMS_TEXT_OPTIONS	"[-inputunicode][-16bit][-flash][-len len][-autolen len][-unicode][-enablevoice][-disablevoice][-enablefax][-disablefax][-enableemail][-disableemail][-voidsms][-replacemessages ID][-replacefile file][-text msgtext][-textutf8 msgtext]"
 #define SMS_PICTURE_OPTIONS	"[-text text][-unicode][-alcatelbmmi]"
 #define SMS_PROFILE_OPTIONS	"[-name name][-bitmap bitmap][-ringtone ringtone]"
 #define SMS_EMS_OPTIONS		"[-unicode][-16bit][-format lcrasbiut][-text text][-unicodefiletext file][-defsound ID][-defanimation ID][-tone10 file][-tone10long file][-tone12 file][-tone12long file][-toneSE file][-toneSElong file][-fixedbitmap file][-variablebitmap file][-variablebitmaplong file][-animation frames file1 ...][-protected number]"
@@ -583,14 +608,8 @@ static GSM_Parameters Parameters[] = {
 	{"displaysms",		2,30, SendSaveDisplaySMS,	{H_SMS,0},			"... (options like in sendsms)"},
 
 	{"addsmsfolder",		1, 1, AddSMSFolder,		{H_SMS,0},			"name"},
-#ifdef HAVE_MYSQL_MYSQL_H
-	{"smsd",			2, 2, SMSDaemon,		{H_SMS,H_SMSD,0},		"MYSQL configfile"},
-#endif
-#ifdef HAVE_POSTGRESQL_LIBPQ_FE_H
-	{"smsd",			2, 2, SMSDaemon,		{H_SMS,H_SMSD,0},		"PGSQL configfile"},
-#endif
-	{"smsd",			2, 2, SMSDaemon,		{H_SMS,H_SMSD,0},		"FILES configfile"},
-	{"sendsmsdsms",		2,30, SendSaveDisplaySMS,	{H_SMS,H_SMSD,0},		"TEXT|WAPSETTINGS|... destination FILES|MYSQL|PGSQL configfile ... (options like in sendsms)"},
+	{"smsd",			2, 2, SMSDaemonObsolete,	{H_Obsolete,0},		""},
+	{"sendsmsdsms",		2,30, SendSMSDSMSObsolete,	{H_Obsolete,0},		""},
 	{"getmmsfolders",		0, 0, GetMMSFolders,		{H_MMS,0},			""},
 	{"getallmms",			0, 1, GetEachMMS,		{H_MMS,0},			"[-save]"},
 	{"geteachmms",		0, 1, GetEachMMS,		{H_MMS,0},			"[-save]"},
@@ -632,7 +651,7 @@ static GSM_Parameters Parameters[] = {
 	{"reset",			1, 1, Reset,			{H_Other,0},			"SOFT|HARD"},
 	{"getprofile",		1, 2, GetProfile,		{H_Settings,0},			"start [stop]"},
 	{"getsecuritystatus",		0, 0, GetSecurityStatus,	{H_Info,0},			""},
-	{"entersecuritycode",		2, 2, EnterSecurityCode,	{H_Other,0},			"PIN|PUK|PIN2|PUK2 code|-"},
+	{"entersecuritycode",		2, 2, EnterSecurityCode,	{H_Other,0},			"PIN|PUK|PIN2|PUK2|PHONE|NETWORK code|-"},
 	{"deletewapbookmark", 	1, 2, DeleteWAPBookmark, 	{H_WAP,0},			"start [stop]"},
 	{"getwapbookmark",		1, 2, GetWAPBookmark,		{H_WAP,0},			"start [stop]"},
 	{"getwapsettings",		1, 2, GetWAPMMSSettings,	{H_WAP,0},			"start [stop]"},
@@ -666,11 +685,11 @@ static GSM_Parameters Parameters[] = {
 	{"savefile",			4, 5, SaveFile,			{H_Backup,H_Memory,0},		"VCARD10|VCARD21 target.vcf file SM|ME location"},
 	{"savefile",			4, 5, SaveFile,			{H_Backup,H_WAP,0},		"BOOKMARK target.url file location"},
 	{"backup",			1, 2, DoBackup,			{H_Backup,H_Memory,H_Calendar,H_ToDo,H_Category,H_Ringtone,H_WAP,H_FM,0},			"file [-yes]"},
-	{"backupsms",			1, 1, BackupSMS,		{H_Backup,H_SMS,0},		"file"},
+	{"backupsms",			1, 2, BackupSMS,		{H_Backup,H_SMS,0},		"file [-yes|-all]"},
 	{"restore",			1, 2, Restore,			{H_Backup,H_Memory,H_Calendar,H_ToDo,H_Category,H_Ringtone,H_WAP,H_FM,0},			"file [-yes]"},
-	{"addnew",			1, 2, AddNew,			{H_Backup,H_Memory,H_Calendar,H_ToDo,H_Category,H_Ringtone,H_WAP,H_FM,0},			"file [-yes]"},
-	{"restoresms",		1, 1, RestoreSMS,		{H_Backup,H_SMS,0},		"file"},
-	{"addsms",			2, 2, AddSMS,			{H_Backup,H_SMS,0},		"folder file"},
+	{"addnew",			1, 4, AddNew,			{H_Backup,H_Memory,H_Calendar,H_ToDo,H_Category,H_Ringtone,H_WAP,H_FM,0},			"file [-yes] [-memory ME|SM|..]"},
+	{"restoresms",		1, 2, RestoreSMS,		{H_Backup,H_SMS,0},		"file [-yes]"},
+	{"addsms",			2, 3, AddSMS,			{H_Backup,H_SMS,0},		"folder file [-yes]"},
 #endif
 	{"clearall",			0, 0, ClearAll,			{H_Memory,H_Calendar,H_ToDo,H_Category,H_Ringtone,H_WAP,H_FM,0},	""},
 	{"networkinfo",		0, 0, NetworkInfo,		{H_Network,0},			""},
@@ -751,7 +770,6 @@ static HelpCategoryDescriptions HelpDescriptions[] = {
 #endif
 	{H_Other,	"other",	N_("Functions that don't fit elsewhere")},
 	{H_Gammu,	"gammu",	N_("Gammu information")},
-	{H_SMSD,	"smsd",		N_("SMS daemon")},
 	{0,		NULL,		NULL}
 /* *INDENT-ON* */
 };
@@ -767,10 +785,12 @@ void HelpGeneral(void)
 
 	HelpHeader();
 
-	printf("%s\n\n", _("Usage: gammu [confign] [nothing|text|textall|binary|errors] <command> [options]"));
-	printf("%s\n", _("First parameter optionally specifies which config section to use (all are probed by default)."));
-	printf("%s\n", _("Use only number of config section, so if config section is [gammu42], use 42."));
-	printf("%s\n\n", _("Second parameter optionally controls debug level, next one specifies actions."));
+	printf("%s\n\n", _("Usage: gammu [parameters] <command> [options]"));
+	printf("%s\n", _("Parameters before command configure gammu behaviour:"));
+	printf("%s\n", _("-c / --config <filename> ... name of configuration file"));
+	printf("%s\n", _("-s / --section <confign> ... section of config file to use, eg. 42"));
+	printf("%s\n", _("-d / --debug <level> ... debug level (nothing|text|textall|textalldate|binary|errors)"));
+	printf("%s\n\n", _("-f / --debug-file <filename> ... file for logging debug messages"));
 
 	printf("%s\n\n", _("Commands can be specified with or without leading --."));
 
@@ -785,11 +805,12 @@ void HelpGeneral(void)
 	printf("\n");
 }
 
-void HelpSplit(int cols, int len, unsigned char *buff)
+void HelpSplit(int cols, int len, const char *buff)
 {
 	int l, len2, pos, split;
-	bool in_opt, first = true;
-	char *remain, spaces[50], buffer[500];
+	gboolean in_opt, first = TRUE;
+	const char *remain;
+	char spaces[50], buffer[500];
 
 	if (cols == 0) {
 		printf(" %s\n", buff);
@@ -808,15 +829,15 @@ void HelpSplit(int cols, int len, unsigned char *buff)
 			while (strlen(remain) > 0) {
 				split = 0;
 				pos = 0;
-				in_opt = false;
+				in_opt = FALSE;
 				if (!first)
 					printf("%s", spaces);
 				while (pos < cols - len && remain[pos] != 0) {
 					if (in_opt && remain[pos] == ']') {
-						in_opt = false;
+						in_opt = FALSE;
 						split = pos;
 					} else if (remain[pos] == '[') {
-						in_opt = true;
+						in_opt = TRUE;
 					} else if (!in_opt
 						   && remain[pos] == ' ') {
 						split = pos - 1;
@@ -828,7 +849,7 @@ void HelpSplit(int cols, int len, unsigned char *buff)
 					printf("%s\n", remain);
 					remain += strlen(remain);
 				} else {
-					first = false;
+					first = FALSE;
 					split++;
 					strncpy(buffer, remain, split);
 					buffer[split] = 0;
@@ -845,7 +866,7 @@ void HelpSplit(int cols, int len, unsigned char *buff)
 void Help(int argc, char *argv[])
 {
 	int i = 0, j = 0, k, cols;
-	bool disp;
+	gboolean disp;
 
 #ifdef TIOCGWINSZ
 	struct winsize w;
@@ -856,16 +877,16 @@ void Help(int argc, char *argv[])
 #endif
 
 	/* Just --help */
-	if (argc == 2) {
+	if (argc == 1) {
 		HelpGeneral();
 		return;
 	}
 
-	if (!strcmp(argv[2], "all")) {
+	if (!strcmp(argv[1], "all")) {
 		HelpHeader();
 	} else {
 		while (HelpDescriptions[i].category != 0) {
-			if (strcasecmp(argv[2], HelpDescriptions[i].option) ==
+			if (strcasecmp(argv[1], HelpDescriptions[i].option) ==
 			    0)
 				break;
 			i++;
@@ -910,20 +931,20 @@ void Help(int argc, char *argv[])
 
 	while (Parameters[j].Function != NULL) {
 		k = 0;
-		disp = false;
-		if (!strcmp(argv[2], "all")) {
+		disp = FALSE;
+		if (!strcmp(argv[1], "all")) {
 			if (j == 0)
-				disp = true;
+				disp = TRUE;
 			if (j != 0) {
 				if (strcmp
 				    (Parameters[j].help,
 				     Parameters[j - 1].help)) {
-					disp = true;
+					disp = TRUE;
 				} else {
 					if (strcmp
 					    (Parameters[j].parameter,
 					     Parameters[j - 1].parameter)) {
-						disp = true;
+						disp = TRUE;
 					}
 				}
 			}
@@ -931,7 +952,7 @@ void Help(int argc, char *argv[])
 			while (Parameters[j].help_cat[k] != 0) {
 				if (Parameters[j].help_cat[k] ==
 				    HelpDescriptions[i].category) {
-					disp = true;
+					disp = TRUE;
 					break;
 				}
 				k++;
@@ -951,10 +972,10 @@ void Help(int argc, char *argv[])
 	}
 }
 
-int ProcessParameters(char start, int argc, char *argv[])
+int ProcessParameters(int start, int argc, char *argv[])
 {
 	int z = 0;
-	bool count_failed = false;
+	gboolean count_failed = FALSE;
 
 	/* Check parameters */
 	while (Parameters[z].Function != NULL) {
@@ -983,7 +1004,7 @@ int ProcessParameters(char start, int argc, char *argv[])
 					printf("%s\n",
 					       gettext(Parameters[z].help));
 				}
-				count_failed = true;
+				count_failed = TRUE;
 			} else if (argc - 2 - start > Parameters[z].max_arg) {
 				if (!count_failed) {
 					if (Parameters[z].min_arg ==
@@ -1004,7 +1025,7 @@ int ProcessParameters(char start, int argc, char *argv[])
 					printf("%s\n",
 					       gettext(Parameters[z].help));
 				}
-				count_failed = true;
+				count_failed = TRUE;
 			} else {
 				Parameters[z].Function(argc - start,
 						       argv + start);
@@ -1029,56 +1050,74 @@ int ProcessParameters(char start, int argc, char *argv[])
 int main(int argc, char *argv[])
 {
 	int start = 0;
-	unsigned int i;
-	int only_config = -1;
-	char *cp, *rss;
+	int i, ret;
+	char *cp, *locales_path, *rss;
 	GSM_Config *smcfg;
 	GSM_Config *smcfg0;
 	GSM_Debug_Info *di;
 	GSM_Error error;
-	INI_Section *cfg = NULL;
 
-	gsm = GSM_AllocStateMachine();
-
-	GSM_InitLocales(NULL);
-
-#ifdef CURL_FOUND
-	curl_global_init(CURL_GLOBAL_ALL);
-#endif
+	gboolean help = FALSE;
+	gboolean debug_level_set = FALSE;
+	gboolean debug_file_set = FALSE;
+	const char *config_file = NULL;
+	int only_config = -1;
 
 	di = GSM_GetGlobalDebug();
 
-#ifdef DEBUG
-	GSM_SetDebugFileDescriptor(stdout, di);
-	GSM_SetDebugLevel("textall", di);
-#endif
-
-	/* Any parameters? */
-	if (argc == 1) {
-		HelpGeneral();
-		printf("%s\n", _("Too few parameters!"));
-		exit(1);
-	}
-
-	/* Help? */
-	if (strcasecmp(argv[1 + start], "--help") == 0 ||
-	    strcasecmp(argv[1 + start], "-h") == 0 ||
-	    strcasecmp(argv[1 + start], "help") == 0) {
-		Help(argc - start, argv + start);
-		exit(1);
-	}
-
-	/* Is first parameter numeric? If so treat it as config that should be loaded. */
-	if (isdigit(argv[1][0])) {
-		only_config = atoi(argv[1]);
-		if (only_config >= 0)
+	/* We don't want to use getopt here */
+	for (i = 1; i < argc; i++) {
+		if (strcasecmp(argv[i], "--help") == 0 ||
+		    strcasecmp(argv[i], "-h") == 0 ||
+		    strcasecmp(argv[i], "help") == 0) {
+			help = TRUE;
 			start++;
-		else
-			only_config = -1;
+		} else if ((strcasecmp(argv[i], "--config") == 0 ||
+		    strcasecmp(argv[i], "-c") == 0) &&
+		    i + 1 < argc) {
+			i++;
+			config_file = argv[i];
+			start += 2;
+		} else if ((strcasecmp(argv[i], "--section") == 0 ||
+		    strcasecmp(argv[i], "-s") == 0) &&
+		    i + 1 < argc) {
+			i++;
+			only_config = atoi(argv[i]);
+			start += 2;
+		} else if ((strcasecmp(argv[i], "--debug") == 0 ||
+		    strcasecmp(argv[i], "-d") == 0) &&
+		    i + 1 < argc) {
+			i++;
+			GSM_SetDebugFileDescriptor(stderr, FALSE, di);
+			GSM_SetDebugLevel(argv[i], di);
+			debug_level_set = TRUE;
+			start += 2;
+		} else if ((strcasecmp(argv[i], "--debug-file") == 0 ||
+		    strcasecmp(argv[i], "-f") == 0) &&
+		    i + 1 < argc) {
+			i++;
+			error = GSM_SetDebugFile(argv[i], di);
+			Print_Error(error);
+			debug_file_set = TRUE;
+			start += 2;
+		} else if (isdigit((int)argv[i][0])) {
+			/* Compatibilitty: config file section */
+			only_config = atoi(argv[i]);
+			if (only_config >= 0)
+				start++;
+			else
+				only_config = -1;
+		} else if (GSM_SetDebugLevel(argv[i], di)) {
+			/* Compatibility: debug level */
+			start++;
+			debug_level_set = TRUE;
+		} else {
+			break;
+		}
 	}
 
-	error = GSM_FindGammuRC(&cfg);
-	if (error != ERR_NONE) {
+	error = GSM_FindGammuRC(&cfg, config_file);
+	if (error != ERR_NONE || cfg == NULL) {
 		if (error == ERR_FILENOTSUPPORTED) {
 			printf_warn("%s\n",
 				    _("Configuration could not be parsed!"));
@@ -1086,6 +1125,57 @@ int main(int argc, char *argv[])
 			printf_warn("%s\n", _("No configuration file found!"));
 		}
 	}
+	locales_path = INI_GetValue(cfg, "gammu", "gammuloc", FALSE);
+	GSM_InitLocales(locales_path);
+#ifdef GETTEXTLIBS_FOUND
+	if (locales_path != NULL) {
+		bindtextdomain("gammu", locales_path);
+	} else {
+#if defined(LOCALE_PATH)
+		bindtextdomain("gammu", LOCALE_PATH);
+#else
+		bindtextdomain("gammu", ".");
+#endif
+	}
+	textdomain("gammu");
+#endif
+
+	gsm = GSM_AllocStateMachine();
+	if (gsm == NULL) {
+		printf_err(_("Failed to allocate memory, aborting!\n"));
+		exit(1);
+	}
+
+#ifdef CURL_FOUND
+	curl_global_init(CURL_GLOBAL_ALL);
+#endif
+
+#ifdef DEBUG
+	if (!debug_level_set) {
+		GSM_SetDebugLevel("textall", di);
+	}
+	if (!debug_file_set) {
+		GSM_SetDebugFileDescriptor(stdout, FALSE, di);
+	}
+#endif
+
+	cp = INI_GetValue(cfg, "gammu", "gammucoding", FALSE);
+	if (cp) {
+		GSM_SetDebugCoding(cp, di);
+	}
+
+	/* Help? */
+	if (help) {
+		Help(argc - start, argv + start);
+		Terminate(0);
+	}
+
+	/* Do we have enough parameters? */
+	if (argc <= start + 1) {
+		HelpGeneral();
+		printf("%s\n", _("Too few parameters!"));
+		Terminate(3);
+	}
 
 	smcfg0 = GSM_GetConfig(gsm, 0);
 
@@ -1096,7 +1186,7 @@ int main(int argc, char *argv[])
 			error = GSM_ReadConfig(cfg, smcfg, only_config);
 			/* Here we get only in first for loop */
 			if (error != ERR_NONE) {
-				printf_err(_("Failed to read [gammu%d] from gammurc!\n"),
+				printf_err(_("Failed to read [gammu%d] section from configuration file (gammurc)!\n"),
 					   only_config);
 				printf_warn("%s\n", _("No configuration read, using builtin defaults!"));
 				GSM_ReadConfig(NULL, smcfg, 0);
@@ -1115,53 +1205,33 @@ int main(int argc, char *argv[])
 		}
 		GSM_SetConfigNum(gsm, GSM_GetConfigNum(gsm) + 1);
 
-		if (cfg != NULL) {
-			cp = INI_GetValue(cfg, "gammu", "gammucoding", false);
-			if (cp) {
-				GSM_SetDebugCoding(cp, di);
-			}
-
-			smcfg->Localize =
-			    INI_GetValue(cfg, "gammu", "gammuloc", false);
-			/* It is safe to pass NULL here */
-			GSM_InitLocales(smcfg->Localize);
-		}
-
 		/* We want to use only one file descriptor for global and state machine debug output */
-		smcfg->UseGlobalDebugFile = true;
+		smcfg->UseGlobalDebugFile = TRUE;
 
 		/* It makes no sense to open several debug logs... */
-		if (i != 0) {
-			strcpy(smcfg->DebugLevel, smcfg0->DebugLevel);
-			free(smcfg->DebugFile);
-			smcfg->DebugFile = strdup(smcfg0->DebugFile);
-		} else {
+		if (i == 0) {
 			/* Just for first config */
 			/* When user gave debug level on command line */
-			if (argc > 1 + start
-			    && GSM_SetDebugLevel(argv[1 + start], di)) {
-				/* Debug level from command line will be used with phone too */
-				strcpy(smcfg->DebugLevel, argv[1 + start]);
-				/* When configured from command line, output to stdout */
-				GSM_SetDebugFileDescriptor(stdout, di);
-				start++;
-			} else {
+			if (!debug_level_set) {
 				/* Try to set debug level from config file */
 				GSM_SetDebugLevel(smcfg->DebugLevel, di);
 			}
 			/* If user gave debug file in gammurc, we will use it */
-			error = GSM_SetDebugFile(smcfg->DebugFile, di);
-			Print_Error(error);
+			if (!debug_file_set) {
+				error = GSM_SetDebugFile(smcfg->DebugFile, di);
+				Print_Error(error);
+			}
 		}
 
 		if (i == 0) {
-			rss = INI_GetValue(cfg, "gammu", "rsslevel", false);
+			rss = INI_GetValue(cfg, "gammu", "rsslevel", FALSE);
 			if (rss) {
 				printf_warn("Configuration option rsslevel is ignored, use '%s' instead\n", "gammu checkversion");
 			}
-			rss = INI_GetValue(cfg, "gammu", "usephonedb", false);
-			if (rss && strcasecmp(rss, "yes") == 0)
-				phonedb = true;
+			rss = INI_GetValue(cfg, "gammu", "usephonedb", FALSE);
+			if (rss) {
+				printf_warn("Configuration option usephonedb is ignored, use '%s' instead\n", "gammu checkfirmware");
+			}
 		}
 
 		/* We wanted to read just user specified configuration. */
@@ -1170,25 +1240,18 @@ int main(int argc, char *argv[])
 		}
 	}
 
-	/* Do we have enough parameters? */
-	if (argc == 1 + start) {
-		HelpGeneral();
-		printf("%s\n", _("Too few parameters!"));
-		exit(-2);
-	}
-
 	/* Check used version vs. compiled */
 	if (!strcasecmp(GetGammuVersion(), VERSION) == 0) {
 		printf_err(_("Version of installed libGammu.so (%s) is different to version of Gammu (%s)\n"),
 			   GetGammuVersion(), VERSION);
-		exit(-1);
+		Terminate(4);
 	}
 
-	ProcessParameters(start, argc, argv);
+	ret = ProcessParameters(start, argc, argv);
 
-	Cleanup();
+	Terminate(ret);
 
-	exit(0);
+	return ret;
 }
 
 /* How should editor hadle tabs in this file? Add editor commands here.
