@@ -15,7 +15,7 @@ void PrintSMSLocation(const GSM_SMSMessage *sms, const GSM_SMSFolders *folders);
  */
 void PrintPhoneNumber(unsigned char *number, const GSM_Backup *Info);
 
-void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, bool eachsms, bool ems, const GSM_Backup *Info, GSM_StateMachine *sm);
+void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, gboolean eachsms, gboolean ems, const GSM_Backup *Info, GSM_StateMachine *sm);
 
 void DisplaySMSFrame(GSM_SMSMessage *SMS, GSM_StateMachine *sm);
 #endif
